Learn R Programming

MScombine (version 1.4)

CombinePolarities: Combine positive and negative matrices

Description

Take positive and negative matrices and combine them by deleting redundat entities.

Usage

CombinePolarities(POSITIVE, NEGATIVE, CommonEntitiesFiltered)

Arguments

POSITIVE

A matrix with positive entities information (Compound Name, Mass, RT, and multiple columns with the area of the compound in samples)

NEGATIVE

A matrix with positive entities information (Compound Name, Mass, RT, and multiple columns with the area of the compound in samples)

CommonEntitiesFiltered

The data set generated with the FilterbyRT function.

Examples

Run this code
# NOT RUN {
CombinePolarities(POSITIVE,NEGATIVE,CommonEntitiesFiltered)
# }

Run the code above in your browser using DataLab