powered by
Take positive and negative matrices and combine them by deleting redundat entities.
CombinePolarities(POSITIVE, NEGATIVE, CommonEntitiesFiltered)
A matrix with positive entities information (Compound Name, Mass, RT, and multiple columns with the area of the compound in samples)
The data set generated with the FilterbyRT function.
# NOT RUN { CombinePolarities(POSITIVE,NEGATIVE,CommonEntitiesFiltered) # }
Run the code above in your browser using DataLab